<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\NewsCategory;
use App\Models\News;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;
use Carbon\Carbon;
use Image;

class NewsCategoryController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        return view('admin.news_category', [
            'news_categories' => NewsCategory::get(),
        ]);
    }

    public function news_category_add()
    {
        return view('admin.news_category_add');
    }

    public function insert(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $request->validate([
            'name' => 'required|unique:news_categories',
            'slug' => 'unique:news_categories'
        ]);

        if ($request->slug == '') {
            $slug = Str::slug($request->name);
        } else {
            $slug = Str::slug($request->slug);
        }

        $count = NewsCategory::where('slug', $slug)->count();
        if ($count != 0) {
            return back()->with('error', A_ERROR_SLUG_EXIST);
        }

        NewsCategory::create([
            'name' => $request->name,
            'slug' => $slug,
            'meta_title' => $request->meta_title,
            'meta_description' => $request->meta_description,
        ]);
        return Redirect()->route('admin.news_category')->with('success', A_SUCCESS_DATA_ADD);
    }

    public function edit_page($id)
    {
        return view('admin.news_category_edit', [
            'news_category_single' => NewsCategory::find($id),
        ]);
    }

    public function edit(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $id = $request->id;
        $request->validate([
            'name' => ['required',Rule::unique('news_categories')->ignore($id),],
            'slug' => [Rule::unique('news_categories')->ignore($id),]
        ]);

        if ($request->slug == '') {
            $slug = Str::slug($request->name);
        } else {
            $slug = Str::slug($request->slug);
        }
        $count = NewsCategory::where('slug', $slug)->where('id', '!=', $id)->count();
        if ($count != 0) {
            return back()->with('error', A_ERROR_SLUG_EXIST);
        }

        $obj = NewsCategory::findOrFail($id);
        $obj->name = $request->name;
        $obj->slug = $slug;
        $obj->meta_title = $request->meta_title;
        $obj->meta_description = $request->meta_description;
        $obj->update();
        return Redirect()->route('admin.news_category')->with('success', A_SUCCESS_DATA_UPDATE);
    }

    public function delete($id)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }
        
        // Check data if in another table
        $total = News::where('category_id', $id)->count();
        if($total > 0) {
            return Redirect()->back()->with('error', 'A_ERROR_DATA_NOT_DELETE_FOR_ANOTHER_TABLE');
        }
        NewsCategory::find($id)->forceDelete();
        return Redirect()->route('admin.news_category')->with('success', A_SUCCESS_DATA_DELETE);
    }
}
